module.exports = {
    parser: '@typescript-eslint/parser',
    parserOptions: {
        sourceType: 'module',
        ecmaVersion: 2018
    },
    plugins: [
        '@typescript-eslint', 'prettier'
    ],
    extends: [
        'eslint:recommended', 'prettier'
    ],
    env: {
        node: true,
        jest: true,
        mocha: true,
        es6: true,
        browser: true,
        commonjs: true
    },
    globals: {
        Symbol: true,
        Atomics: 'readonly',
        SharedArrayBuffer: 'readonly',
        __DEV__: true
    },
    rules: {
        indent: [
            2, 2, {
                SwitchCase: 1
            },
        ],
        'no-mixed-spaces-and-tabs': 2,
        quotes: [
            2, 'single', 'avoid-escape'
        ],
        semi: 2,
        'no-extra-semi': 2,
        'no-trailing-spaces': 2,
        'eol-last': 2,
        'no-console': 0,
        'no-debugger': 2,
        strict: [
            'error', 'global'
        ],
        'import/first': 0,
        'no-eval': 2,
        eqeqeq: [
            'error', 'always'
        ],
        'no-eq-null': 2,
        'new-cap': 2,
        'no-plusplus': 2,
        'space-unary-ops': [
            2, {
                words: true,
                nonwords: false
            }
        ],
        'space-infix-ops': 2,
        'no-undef': 2,
        'prefer-const': 2,
        'no-const-assign': 2,
        'no-var': 2,
        'no-unused-vars': [
            2, {
                vars: 'all',
                args: 'none'
            },
        ],
        'one-var': [
            2, {
                uninitialized: 'always',
                initialized: 'never'
            },
        ],
        'no-unreachable': 2,
        'no-duplicate-case': 2,
        'no-dupe-keys': 2,
        'dot-notation': 0,
        'no-dupe-args': 2,
        'comma-style': [
            2, 'last'
        ],
        'key-spacing': [
            2, {
                beforeColon: false
            }
        ],
        'no-spaced-func': 2,
        'keyword-spacing': [
            2, {
                after: true
            }
        ],
        'brace-style': [
            2, '1tbs', {
                allowSingleLine: true
            },
        ],
        curly: [
            2, 'all'
        ],
        'space-in-parens': [
            2, 'never'
        ],
        'array-bracket-spacing': [
            2, 'never'
        ],
        'space-before-function-paren': 2,
        'spaced-comment': [
            2, 'always'
        ],
        'lines-around-comment': 2,
        'no-multi-str': 2,
        'wrap-iife': [
            2, 'outside'
        ],
        yoda: [
            2, 'never'
        ],
        '@typescript-eslint/interface-name-prefix': 0,
        '@typescript-eslint/explicit-function-return-type': 0,
        '@typescript-eslint/no-explicit-any': 0,
        '@typescript-eslint/no-use-before-define': 0,
        '@typescript-eslint/no-non-null-assertion': 2,
        'prettier/prettier': 2
    }
};
